function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

require('bootstrap/dist/css/bootstrap.css');
var React = require('react');
var React__default = _interopDefault(React);
var PropTypes = _interopDefault(require('prop-types'));
var lodash = require('lodash');

var Alert = function Alert(_ref) {
  var type = _ref.type,
      children = _ref.children;
  return /*#__PURE__*/React__default.createElement("div", {
    className: "alert alert-" + type
  }, children);
};

Alert.protoTypes = {
  type: PropTypes.oneOf(["primary", "secondary", "success", "danger", "warning", "info", "light", "dark"]).isRequired,
  children: PropTypes.oneOfType([PropTypes.string, PropTypes.element]).isRequired
};

var Button = function Button(_ref) {
  var type = _ref.type,
      outline = _ref.outline,
      size = _ref.size,
      block = _ref.block,
      disabled = _ref.disabled,
      children = _ref.children;
  var outlineClass = outline ? "btn-outline-" + type : "";
  var sizeClass = !lodash.isNil(size) ? "btn-" + size : "";
  var blockClass = block ? "btn-block" : "";
  return /*#__PURE__*/React__default.createElement("button", {
    type: "button",
    className: "btn btn-" + type + " " + outlineClass + " " + sizeClass + " " + blockClass,
    disabled: disabled
  }, children);
};

Button.propTypes = {
  type: PropTypes.oneOf(["primary", "secondary", "success", "danger", "warning", "info", "light", "dark", "link"]).isRequired,
  outline: PropTypes.bool,
  size: PropTypes.oneOf(["lg", "sm"]),
  block: PropTypes.bool,
  disabled: PropTypes.bool
};
Button.defaultProps = {
  outline: false,
  size: null,
  block: false,
  disabled: false
};

var Form = function Form(_ref) {
  var children = _ref.children;
  return /*#__PURE__*/React__default.createElement("form", null, /*#__PURE__*/React__default.createElement(Fragment, null, children));
};

Form.propTypes = {
  children: PropTypes.element.isRequired
};

var FormGroup = function FormGroup(_ref) {
  var children = _ref.children;
  return /*#__PURE__*/React__default.createElement("div", {
    className: "form-group"
  }, children);
};

FormGroup.propTypes = {
  children: PropTypes.element.isRequired
};

var TextInput = function TextInput(_ref) {
  var labelText = _ref.labelText,
      inputId = _ref.inputId,
      inputType = _ref.inputType,
      inputValue = _ref.inputValue,
      inputPlaceHolder = _ref.inputPlaceHolder,
      onChangeText = _ref.onChangeText,
      helperId = _ref.helperId,
      helperText = _ref.helperText;

  var renderLabel = function renderLabel() {
    return !lodash.isEmpty(labelText) ? /*#__PURE__*/React__default.createElement("label", {
      forHtml: inputId
    }, labelText) : null;
  };

  var renderHelper = function renderHelper() {
    return !lodash.isEmpty(helperId) ? /*#__PURE__*/React__default.createElement("small", {
      id: helperId,
      className: "form-text text-muted"
    }, helperText) : null;
  };

  return /*#__PURE__*/React__default.createElement(Fragment, null, renderLabel(), /*#__PURE__*/React__default.createElement("input", {
    type: inputType,
    className: "form-control",
    id: inputId,
    value: inputValue,
    onChangeText: onChangeText,
    placeholder: inputPlaceHolder,
    "aria-describedby": helperId
  }), renderHelper());
};

TextInput.propTypes = {
  labelText: PropTypes.string,
  inputId: PropTypes.string.isRequired,
  inputType: PropTypes.string,
  inputValue: PropTypes.string.isRequired,
  inputPlaceHolder: PropTypes.string,
  onChangeText: PropTypes.func.isRequired,
  helperId: PropTypes.string,
  helperText: PropTypes.string
};
TextInput.defaultProps = {
  labelText: "",
  inputType: "text",
  inputPlaceHolder: "",
  helperId: "",
  helperText: ""
};

var Checkbox = function Checkbox(_ref) {
  var inputId = _ref.inputId,
      inputValue = _ref.inputValue,
      labelText = _ref.labelText,
      onChange = _ref.onChange;
  return /*#__PURE__*/React__default.createElement("div", {
    className: "form-check form-check-inline"
  }, /*#__PURE__*/React__default.createElement("input", {
    className: "form-check-input",
    type: "checkbox",
    id: inputId,
    value: inputValue,
    onChange: onChange
  }), /*#__PURE__*/React__default.createElement("label", {
    className: "form-check-label",
    forHtml: inputId
  }, labelText));
};

Checkbox.propTypes = {
  inputId: PropTypes.string.isRequired,
  inputValue: PropTypes.bool.isRequired,
  labelText: PropTypes.string,
  onChange: PropTypes.func.isRequired
};
Checkbox.defaultProps = {
  labelText: ""
};

var NavBar = function NavBar(_ref) {
  var title = _ref.title,
      items = _ref.items,
      actionButton = _ref.actionButton;

  var _useState = React.useState(false),
      toggler = _useState[0],
      setToggler = _useState[1];

  return /*#__PURE__*/React__default.createElement("nav", {
    className: "navbar navbar-expand-xl navbar-dark bg-dark"
  }, /*#__PURE__*/React__default.createElement("a", {
    className: "navbar-brand",
    href: "#"
  }, title), /*#__PURE__*/React__default.createElement("button", {
    className: "navbar-toggler " + (toggler && "collapsed"),
    type: "button",
    "data-toggle": "collapse",
    "data-target": "#navbarsExample02",
    "aria-controls": "navbarsExample02",
    "aria-expanded": toggler,
    "aria-label": "Toggle navigation",
    onClick: function onClick() {
      return setToggler(!toggler);
    }
  }, /*#__PURE__*/React__default.createElement("span", {
    className: "navbar-toggler-icon"
  })), /*#__PURE__*/React__default.createElement("div", {
    className: "collapse navbar-collapse " + (toggler && "show"),
    id: "navbarsExample02"
  }, /*#__PURE__*/React__default.createElement("ul", {
    className: "navbar-nav mr-auto"
  }, items.map(function (item) {
    return item;
  })), /*#__PURE__*/React__default.createElement("div", {
    className: "my-2 my-lg-0"
  }, actionButton)));
};

NavBar.propTypes = {
  title: PropTypes.string.isRequired,
  items: PropTypes.arrayOf([PropTypes.element]).isRequired,
  actionButton: PropTypes.element
};
NavBar.defaultProps = {
  actionButton: null
};

exports.Alert = Alert;
exports.Button = Button;
exports.Checkbox = Checkbox;
exports.Form = Form;
exports.FormGroup = FormGroup;
exports.NavBar = NavBar;
exports.TextInput = TextInput;
//# sourceMappingURL=index.js.map
